@@ -30,30 +30,34 @@ __all__ = ["MacroManager", "MacroExecutor", "is_macro"]
 
 __docformat__ = 'restructuredtext'
 
-import sys
-import os
-import inspect
-import copy
 import re
+import os
+import sys
+import copy
+import inspect
 import functools
 import traceback
 
 from lxml import etree
 
 from PyTango import DevFailed
-from taurus.core.util import Logger, CodecFactory
+
+from taurus.core.util.log import Logger
+from taurus.core.util.codecs import  CodecFactory
 
 from sardana.sardanadefs import ElementType
 from sardana.sardanamodulemanager import ModuleManager
 from sardana.sardanaexception import format_exception_only_str
 from sardana.sardanautils import is_pure_str, is_non_str_seq
 
-from .msmanager import MacroServerManager
-from .msmetamacro import MACRO_TEMPLATE, MacroLibrary, MacroClass, MacroFunction
-from .msparameter import ParamDecoder
-from .macro import Macro, MacroFunc
-from .msexception import UnknownMacroLibrary, LibraryError, UnknownMacro, \
-    MissingEnv, AbortException, StopException, MacroServerException
+from sardana.macroserver.msmanager import MacroServerManager
+from sardana.macroserver.msmetamacro import MACRO_TEMPLATE, MacroLibrary, \
+    MacroClass, MacroFunction
+from sardana.macroserver.msparameter import ParamDecoder
+from sardana.macroserver.macro import Macro, MacroFunc
+from sardana.macroserver.msexception import UnknownMacroLibrary, \
+    LibraryError, UnknownMacro, MissingEnv, AbortException, StopException, \
+    MacroServerException, UnknownEnv
 
 _BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -208,7 +212,7 @@ class MacroManager(MacroServerManager):
         for p in reversed(path):
             try:
                 for f in os.listdir(p):
-                    name,ext = os.path.splitext(f)
+                    name, ext = os.path.splitext(f)
                     if name.startswith("_"):
                         continue
                     if ext.endswith('py'):
@@ -453,7 +457,7 @@ class MacroManager(MacroServerManager):
         try:
             m = mod_manager.reloadModule(module_name, path)
         except:
-            exc_info=sys.exc_info()
+            exc_info = sys.exc_info()
         macro_lib = None
 
         params = dict(module=m, name=module_name,
@@ -641,7 +645,7 @@ class MacroManager(MacroServerManager):
         out_par_list = ParamDecoder(door, macro_meta, in_par_list)
         return macro_meta, in_par_list, out_par_list
 
-    def strMacroParamValues(self,par_list):
+    def strMacroParamValues(self, par_list):
         """strMacroParamValues(list<string> par_list) -> list<string>
 
            Creates a short string representantion of the parameter values list.
@@ -653,7 +657,7 @@ class MacroManager(MacroServerManager):
         ret = []
         for p in par_list:
             param_str = str(p)
-            if len(param_str)>9:
+            if len(param_str) > 9:
                 param_str = param_str[:9] + "..."
             ret.append(param_str)
         return ret
@@ -1130,11 +1134,12 @@ class MacroExecutor(Logger):
             self._macro_stack.append(macro_obj)
             for step in macro_obj.exec_():
                 self.sendMacroStatus((step,))
-
+            result = macro_obj.getResult()
+            # sending result only if we are the top most macro
             if macro_obj.hasResult() and macro_obj.getParentMacro() is None:
-                result = self.__preprocessResult(macro_obj.getResult())
-                door.debug("sending result %s", result)
-                self.sendResult(result)
+                result_repr = self.__preprocessResult(result)
+                door.debug("sending result %s", result_repr)
+                self.sendResult(result_repr)
         except AbortException as ae:
             macro_exp = ae
         except StopException as se:
@@ -1184,6 +1189,19 @@ class MacroExecutor(Logger):
             raise macro_exp
         self.debug("[ END ] runMacro %s" % desc)
         self._popMacro()
+        
+        # decide whether to preserve the macro data
+        env_var_name = 'PreserveMacroData' 
+        try:
+            preserve_macro_data = macro_obj.getEnv(env_var_name)
+        except UnknownEnv:
+            preserve_macro_data = True
+        if not preserve_macro_data:
+            self.debug('Macro data will not be preserved. ' + \
+                       'Set "%s" environment variable ' % env_var_name + \
+                       'to True in order to change it.')
+            self._macro_pointer = None
+
         return result
 
     def _popMacro(self):
@@ -1191,10 +1209,7 @@ class MacroExecutor(Logger):
         length = len(self._macro_stack)
         if length > 0:
             self._macro_pointer = self._macro_stack[-1]
-        #disable macro data for now. Comment following lines to enable it again
-        else:
-            self._macro_pointer = None
-
+        
     def sendState(self, state):
         return self.door.set_state(state)
 
